@@ -12,10 +12,14 @@ impl super::Node for Node {
         left_refs.append(&mut right_refs);
         (Box::new(Self { left, right }), left_refs)
     }
-    fn calc(&self, calculated_table: &Vec<Vec<Value>>) -> Value {
-        let left = self.left.calc(calculated_table);
-        let right = self.right.calc(calculated_table);
-        match (left, right) {
+    fn calc(
+        &mut self,
+        calculated_table: &Vec<Vec<Value>>,
+    ) -> (Value, Vec<(usize, usize)>, Vec<(usize, usize)>) {
+        let mut left = self.left.calc(calculated_table);
+        let mut right = self.right.calc(calculated_table);
+
+        let value = match (left.0, right.0) {
             (Value::Integer(left), Value::Integer(right)) => {
                 if right == 0 {
                     Value::Float(f64::INFINITY)
@@ -27,6 +31,10 @@ impl super::Node for Node {
             (Value::Float(left), Value::Integer(right)) => Value::Float(left / right as f64),
             (Value::Float(left), Value::Float(right)) => Value::Float(left / right),
             _ => Value::Error,
-        }
+        };
+
+        left.1.append(&mut right.1);
+        left.2.append(&mut right.2);
+        (value, left.1, left.2)
     }
 }
