@@ -16,26 +16,22 @@ pub enum Value {
 
 impl Node for Value {
     fn new(seqs: Vec<Vec<Token>>) -> (Box<ThreadSafeNode>, Vec<(usize, usize)>) {
-        let val = seqs[0][0].clone();
-        match val {
+        match seqs[0][0].clone() {
             Token::Integer(x) => (Box::new(Value::Integer(x)), vec![]),
             Token::Float(x) => (Box::new(Value::Float(x)), vec![]),
             Token::String(x) => (Box::new(Value::String(x)), vec![]),
             Token::Boolean(x) => (Box::new(Value::Boolean(x)), vec![]),
             Token::Ref(x, y) => (Box::new(Value::Ref(x, y)), vec![(x, y)]),
-            Token::Range(x1, y1, x2, y2) => (Box::new(Value::Range(x1, y1, x2, y2)), {
-                let rx = x1.min(x2)..=x1.max(x2);
-                let ry = y1.min(y2)..=y1.max(y2);
-                rx.flat_map(|x| {
-                    return ry.clone().map(move |y| (x, y));
-                })
-                .collect()
-            }),
+            Token::Range(x1, y1, x2, y2) => (Box::new(Value::Range(x1, y1, x2, y2)), vec![]),
             _ => (Box::new(Value::Error), vec![]),
         }
     }
-    fn calc(&self, calculated_table: &Vec<Vec<Value>>) -> Value {
-        match self {
+
+    fn calc(
+        &mut self,
+        calculated_table: &Vec<Vec<Value>>,
+    ) -> (Value, Vec<(usize, usize)>, Vec<(usize, usize)>) {
+        let value = match self {
             Value::Ref(x, y) => {
                 if let Some(row) = calculated_table.get(*y) {
                     if let Some(item) = row.get(*x) {
@@ -48,7 +44,9 @@ impl Node for Value {
                 }
             }
             _ => self.clone(),
-        }
+        };
+
+        (value, vec![], vec![])
     }
 }
 
